@@ -377,6 +377,7 @@ addition to the directories listed here."
   :group 'psgml)
 (put 'sgml-system-path 'sgml-type 'list)
 
+;; This isn't used now
 (defun sgml-parse-colon-path (cd-path)
   "Explode a colon-separated list of paths into a string list."
   (let (cd-list (cd-start 0) cd-colon)
@@ -391,11 +392,13 @@ addition to the directories listed here."
       (setq cd-start (+ cd-colon 1)))
     cd-list))
 
-(defcustom sgml-public-map (sgml-parse-colon-path
+(defcustom sgml-public-map (split-path
 			    (or (getenv "SGML_PATH")
-				;; Wing change
-				(concat "%S:" (directory-file-name
-					       sgml-data-directory)
+				;; Wing/Krause change
+				(concat "%S"
+					path-separator
+					(directory-file-name
+					 sgml-data-directory)
 					"/%o/%c/%d")))
   
   "*Mapping from public identifiers to file names.
@@ -424,13 +427,14 @@ This variable is automatically local to the buffer."
 (make-variable-buffer-local 'sgml-local-catalogs)
 (put 'sgml-local-catalogs 'sgml-type 'list)
 
-(defcustom sgml-catalog-files (sgml-parse-colon-path
-			    (or (getenv "SGML_CATALOG_FILES")
-				;; Wing addition
-				(concat "CATALOG:"
-                                       (expand-file-name
-                                        "CATALOG"
-                                        sgml-data-directory))))
+(defcustom sgml-catalog-files (split-path
+			       (or (getenv "SGML_CATALOG_FILES")
+				   ;; Wing/Krause addition
+				   (concat "CATALOG"
+					   path-separator
+					   (expand-file-name
+					    "CATALOG"
+					    sgml-data-directory))))
   "*List of catalog entry files.
 The files are in the format defined in the SGML Open Draft Technical
 Resolution on Entity Management."
